Index: Source/core/css/CSSParser-in.cpp |
diff --git a/Source/core/css/CSSParser-in.cpp b/Source/core/css/CSSParser-in.cpp |
index ccd8e71085b144afa925fa5106c715d3b441ae91..c35945c502a1f35c900fb2a21622f9844a1c9b56 100644 |
--- a/Source/core/css/CSSParser-in.cpp |
+++ b/Source/core/css/CSSParser-in.cpp |
@@ -9120,11 +9120,13 @@ PassRefPtr<CSSValue> CSSParser::parseTextIndent() |
} |
} |
-#if ENABLE(CSS3_TEXT) |
+ if (!RuntimeEnabledFeatures::css3TextEnabled()) |
+ return 0; |
+ |
// The case where text-indent has only <length>(or <percentage>) value |
// is handled above if statement even though CSS3_TEXT is enabled. |
// [ [ <length> | <percentage> ] && -webkit-each-line ] | inherit |
if (m_valueList->size() != 2) |
return 0; |
@@ -9132,20 +9134,19 @@ PassRefPtr<CSSValue> CSSParser::parseTextIndent() |
CSSParserValue* secondValue = m_valueList->next(); |
CSSParserValue* lengthOrPercentageValue = 0; |
- // [ <length> | <percentage> ] -webkit-each-line |
- if (validUnit(firstValue, FLength | FPercent) && secondValue->id == CSSValueWebkitEachLine) |
+ // [ <length> | <percentage> ] each-line |
+ if (validUnit(firstValue, FLength | FPercent) && secondValue->id == CSSValueEachLine) |
lengthOrPercentageValue = firstValue; |
- // -webkit-each-line [ <length> | <percentage> ] |
- else if (firstValue->id == CSSValueWebkitEachLine && validUnit(secondValue, FLength | FPercent)) |
+ // each-line [ <length> | <percentage> ] |
+ else if (firstValue->id == CSSValueEachLine && validUnit(secondValue, FLength | FPercent)) |
lengthOrPercentageValue = secondValue; |
if (lengthOrPercentageValue) { |
list->append(createPrimitiveNumericValue(lengthOrPercentageValue)); |
- list->append(cssValuePool().createIdentifierValue(CSSValueWebkitEachLine)); |
+ list->append(cssValuePool().createIdentifierValue(CSSValueEachLine)); |
m_valueList->next(); |
return list.release(); |
} |
-#endif |
return 0; |
} |
@@ -9120,11 +9120,13 @@ PassRefPtr<CSSValue> CSSParser::parseTextIndent() |
// The case where text-indent has only <length>(or <percentage>) value |
- // is handled above if statement even though CSS3_TEXT is enabled. |
+ // is handled above if statement even though css3TextEnabled() returns true. |
- // [ [ <length> | <percentage> ] && -webkit-each-line ] | inherit |
+ // [ [ <length> | <percentage> ] && each-line ] | inherit |
if (m_valueList->size() != 2) |
return 0; |